==> demo-center-api-0.0.12-sources.jar: cn/com/duiba/demo/center/api/dto/OrderListDto.java <==
package cn.com.duiba.demo.center.api.dto;

import java.io.Serializable;
import java.sql.Timestamp;

/**
 * Created by xiangyaohui on 2019/3/20
 */
public class OrderListDto implements Serializable {
    private Long id;
    private String uuid;
    private Long order_number;
    private String order_express;
    private String express_num;
    private String order_state;
    private Timestamp order_time;
    private String goods_name;
    private String goods_price;
    private int goods_num;
    private String person_name;
    private String person_tel;
    private String person_address;

    public void setId(Long id) {
        this.id = id;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public void setOrder_express(String order_express) {
        this.order_express = order_express;
    }

    public void setGoods_name(String goods_name) {
        this.goods_name = goods_name;
    }

    public void setGoods_num(int goods_num) {
        this.goods_num = goods_num;
    }

    public void setGoods_price(String goods_price) {
        this.goods_price = goods_price;
    }

    public void setPerson_name(String person_name) {
        this.person_name = person_name;
    }

    public void setPerson_address(String person_address) {
        this.person_address = person_address;
    }

    public void setExpress_num(String express_num) {
        this.express_num = express_num;
    }

    public void setOrder_number(Long order_number) {
        this.order_number = order_number;
    }

    public void setPerson_tel(String person_tel) {
        this.person_tel = person_tel;
    }

    public void setOrder_time(Timestamp order_time) {
        this.order_time = order_time;
    }

    public void setOrder_state(String order_state) {
        this.order_state = order_state;
    }

    public Long getId() {
        return id;
    }

    public String getUuid() {
        return uuid;
    }

    public String getOrder_express() {
        return order_express;
    }

    public String getGoods_name() {
        return goods_name;
    }

    public String getPerson_name() {
        return person_name;
    }

    public String getPerson_address() {
        return person_address;
    }

    public String getExpress_num() {
        return express_num;
    }

    public String getPerson_tel() {
        return person_tel;
    }

    public Timestamp getOrder_time() {
        return order_time;
    }

    public String getOrder_state() {
        return order_state;
    }

    public int getGoods_num() {
        return goods_num;
    }

    public Long getOrder_number() {
        return order_number;
    }

    public String getGoods_price() {
        return goods_price;
    }

    @Override
    public String toString(){
        return "orders:{id=" + id +
                ",uuid=" + uuid +
                ",order_number=" + order_number +
                ",order_express=" + order_express +
                ",express_num=" + express_num +
                ",order_state=" + order_state +
                ",order_time=" + order_time +
                ",goods_name=" + goods_name +
                ",goods_price=" + goods_price +
                ",goods_num=" + goods_num +
                ",person_name=" + person_name +
                ",person_tel=" + person_tel +
                ",person_address=" + person_address + "}";
    }
}

==> demo-center-api-0.1.2-sources.jar: cn/com/duiba/demo/center/api/dto/OrderListDto.java <==
package cn.com.duiba.demo.center.api.dto;

import java.io.Serializable;
import java.sql.Timestamp;

/**
 * Created by xiangyaohui on 2019/3/20
 */
public class OrderListDto implements Serializable {
    private Long id;
    private String uuid;
    private Long order_number;
    private String order_express;
    private String express_num;
    private int order_state; // 订单状态 1取消 2待发货 3已发货
    private Timestamp order_time;
    private String goods_name;
    private String goods_price;
    private int goods_num;
    private String person_name;
    private String person_tel;
    private String person_address;

    public void setId(Long id) {
        this.id = id;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public void setOrder_express(String order_express) {
        this.order_express = order_express;
    }

    public void setGoods_name(String goods_name) {
        this.goods_name = goods_name;
    }

    public void setGoods_num(int goods_num) {
        this.goods_num = goods_num;
    }

    public void setGoods_price(String goods_price) {
        this.goods_price = goods_price;
    }

    public void setPerson_name(String person_name) {
        this.person_name = person_name;
    }

    public void setPerson_address(String person_address) {
        this.person_address = person_address;
    }

    public void setExpress_num(String express_num) {
        this.express_num = express_num;
    }

    public void setOrder_number(Long order_number) {
        this.order_number = order_number;
    }

    public void setPerson_tel(String person_tel) {
        this.person_tel = person_tel;
    }

    public void setOrder_time(Timestamp order_time) {
        this.order_time = order_time;
    }

    public void setOrder_state(int order_state) {
        this.order_state = order_state;
    }

    public Long getId() {
        return id;
    }

    public String getUuid() {
        return uuid;
    }

    public String getOrder_express() {
        return order_express;
    }

    public String getGoods_name() {
        return goods_name;
    }

    public String getPerson_name() {
        return person_name;
    }

    public String getPerson_address() {
        return person_address;
    }

    public String getExpress_num() {
        return express_num;
    }

    public String getPerson_tel() {
        return person_tel;
    }

    public Timestamp getOrder_time() {
        return order_time;
    }

    public int getOrder_state() {
        return order_state;
    }

    public int getGoods_num() {
        return goods_num;
    }

    public Long getOrder_number() {
        return order_number;
    }

    public String getGoods_price() {
        return goods_price;
    }

    @Override
    public String toString(){
        return "orders:{id=" + id +
                ",uuid=" + uuid +
                ",order_number=" + order_number +
                ",order_express=" + order_express +
                ",express_num=" + express_num +
                ",order_state=" + order_state +
                ",order_time=" + order_time +
                ",goods_name=" + goods_name +
                ",goods_price=" + goods_price +
                ",goods_num=" + goods_num +
                ",person_name=" + person_name +
                ",person_tel=" + person_tel +
                ",person_address=" + person_address + "}";
    }
}
